==> haskell-rere-0.2.0.1-110-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rere.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rere
version:              0.2.0.1
visibility:           public
id:                   rere-0.2.0.1-65n50BFY7yVK2wnRtr4tAL
key:                  rere-0.2.0.1-65n50BFY7yVK2wnRtr4tAL
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  14004b680484e65b65324febf071384f
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rere
hs-libraries:         HSrere-0.2.0.1-65n50BFY7yVK2wnRtr4tAL
depends:
    QuickCheck-2.14.3-DWdp4hEhOPY12RnA9FiTGL base-4.17.2.1
    containers-0.6.7 fin-0.3.2-8e22AU9sx1YABuBtn5yzBf parsec-3.1.16.1
    transformers-0.5.6.2 vec-0.5-7zBw2pHQcjf2AYR8ZGdEm7

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rere-0.2.0.1-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rere.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rere
version:              0.2.0.1
visibility:           public
id:                   rere-0.2.0.1-EzX2LLgImDc3gIkf7wiAgb
key:                  rere-0.2.0.1-EzX2LLgImDc3gIkf7wiAgb
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  636ca8af187aa8929fe7eb6cdaecb8e5
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rere
hs-libraries:         HSrere-0.2.0.1-EzX2LLgImDc3gIkf7wiAgb
depends:
    QuickCheck-2.14.3-Jxw7miv7LXh9Jg8jeeWydd base-4.17.2.1
    containers-0.6.7 fin-0.3.2-C1bsnuBRstdH6TzH7BtgOK parsec-3.1.16.1
    transformers-0.5.6.2 vec-0.5-ALvwGwwaEBi80DfrP3jRdH

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
